<?php
/**
 * The core plugin class.
 *
 * @since      1.0.0
 * @package    litesmash
 * @subpackage litesmash/includes
 * @author     litesmash <contact@litesmash.com>
 */
class LiteSmash {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 */
	public function __construct() {
		if ( defined( 'LS_VERSION' ) ) {
			$this->version = LS_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'litesmash';
	
		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
		$this->define_ls_viral_campaign_hooks();
		$this->define_traffic_hooks();
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Plugin_Name_Loader. Orchestrates the hooks of the plugin.
	 * - Plugin_Name_i18n. Defines internationalization functionality.
	 * - Plugin_Name_Admin. Defines all hooks for the admin area.
	 * - Plugin_Name_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 */
	private function load_dependencies() {

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-litesmash-loader.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-litesmash-i18n.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-litesmash-admin.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-litesmash-public.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'ls-viral-campaign/class-wpls-viral-builder-traffic.php';		
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'traffic/class-wpls-email-traffic.php';
		$this->loader = new LiteSmash_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Plugin_Name_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 */
	private function set_locale() {

		$plugin_i18n = new LiteSmash_i18n();
		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 */
	private function define_admin_hooks() {

		$plugin_admin = new LiteSmash_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		// Add menu item
		$this->loader->add_action( 'admin_menu', $plugin_admin, 'ls_admin_menu' );

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 */
	private function define_public_hooks() {

		$plugin_public = new LiteSmash_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );

	}

	private function define_ls_viral_campaign_hooks() {
		$ls_viral_builder_plugin_admin = new Wpls_vbuilder_traffic( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $ls_viral_builder_plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $ls_viral_builder_plugin_admin, 'enqueue_scripts' );

		$this->loader->add_action( 'admin_menu', $ls_viral_builder_plugin_admin, 'add_plugin_vbuilder_admin_menu' );

		$this->loader->add_action( 'wp_ajax_nopriv_ls_vbuilder_opt_result', $ls_viral_builder_plugin_admin, 'ajax_wpls_vbuilder_opt_result' );
		$this->loader->add_action( 'wp_ajax_ls_vbuilder_opt_result', $ls_viral_builder_plugin_admin, 'ajax_wpls_vbuilder_opt_result' );
		
		$this->loader->add_action( 'wp_ajax_nopriv_ls_vbuilder_frontend_opt_result', $ls_viral_builder_plugin_admin, 'ajax_wpls_vbuilder_frontend_opt_result' );
		$this->loader->add_action( 'wp_ajax_ls_vbuilder_frontend_opt_result', $ls_viral_builder_plugin_admin, 'ajax_wpls_vbuilder_frontend_opt_result' );		

		$this->loader->add_action( 'wp_ajax_nopriv_ls_vbuilder_frontend_template2_opt_result', $ls_viral_builder_plugin_admin, 'ajax_wpls_vbuilder_frontend_template2_opt_result' );
		$this->loader->add_action( 'wp_ajax_ls_vbuilder_frontend_template2_opt_result', $ls_viral_builder_plugin_admin, 'ajax_wpls_vbuilder_frontend_template2_opt_result' );		
		
		$this->loader->add_action( 'wp_ajax_nopriv_ls_option_result', $ls_viral_builder_plugin_admin, 'ajax_wpls_option_result' );
		$this->loader->add_action( 'wp_ajax_ls_option_result', $ls_viral_builder_plugin_admin, 'ajax_wpls_option_result' );		
	}

	private function define_traffic_hooks() {

		$plugin_admin = new Wpls_email_traffic( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );

		// Add menu item
		$this->loader->add_action( 'admin_menu', $plugin_admin, 'add_plugin_admin_menu' );
	}
	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}


	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
